.. yellowbrick documentation master file, created by
   sphinx-quickstart on Tue Jul  5 19:45:43 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=======================================
Welcome to yellowbrick's documentation!
=======================================

Yellowbrick is a suite of visual analysis and diagnostic tools to facilitate feature selection, model selection, and parameter tuning for machine learning. All visualizations are generated in Matplotlib.

Custom ``yellowbrick`` visualization tools include:

Tools for feature analysis and selection
----------------------------------------

 - Boxplots ("box-and-whisker" plots)
 - Violinplots
 - Histograms
 - Scatter plot matrices ("sploms")
 - Radial visualizations ("radviz")
 - Parallel coordinates
 - Jointplots
 - Rank 1D
 - Rank 2D


Tools for model evaluation
--------------------------

Classification
^^^^^^^^^^^^^^
 - ROC-AUC curves
 - Classification heatmaps
 - Class balance charts

Regression
^^^^^^^^^^
 - Prediction error plots
 - Residual plots
 - Most informative features

Clustering
^^^^^^^^^^
 - Silhouettes
 - Density measures


Tools for parameter tuning
--------------------------

- Validation curves
- Gridsearch heatmap


=========
Contents:
=========

.. toctree::
   :maxdepth: 4

   introduction
   setup
   examples/examples
   api/modules
   evaluation
   about

==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
